﻿using MediatR;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Sharing.Notifications.HuiJu;
using Sharing.Province.HuiJu.Send;
using Sharing.Province.Other;
using Sharing.Province.XieTong.Receive;

namespace Sharing.Application.Province
{
    /// <summary>
    /// 后台定时任务
    /// </summary>
    public class PushDataBgService : BackgroundService
    {
        private readonly IServiceScopeFactory _serviceScopeFactory;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="serviceScopeFactory"></param>
        public PushDataBgService(IServiceScopeFactory serviceScopeFactory)
        {
            _serviceScopeFactory = serviceScopeFactory;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="stoppingToken"></param>
        /// <returns></returns>
        protected override async Task ExecuteAsync(CancellationToken stoppingToken)
        {
            //10分钟扫描一次数据库
            using var sc = _serviceScopeFactory.CreateScope();
            var time = TimeSpan.FromSeconds(60 * 10);
            while (!stoppingToken.IsCancellationRequested)
            {
                using var scope = _serviceScopeFactory.CreateScope();
                var _waitingPushDataRepository = scope.ServiceProvider.GetService<IWaitingPushDataRepository>();
                var _mediator = scope.ServiceProvider.GetService<IMediator>();

                //查询待推送数据
                var listData = await _waitingPushDataRepository
                       .Queryable()
                       .OrderByDescending(p => p.Priority)
                       .ToListAsync();
                if (listData != null && listData.Count > 0)
                {
                    List<SubmitCaseProcess> submitCaseProcesses = new(); //服务工单处理过程
                    List<SubmitCaseResult> submitCaseResults = new(); //服务工单处理结果
                    List<SubmitVisitInfo> submitVisitInfos = new(); //服务工单回访评价
                    List<GetCaseMaterialInfo> getCaseMaterialInfos = new();//附件上传处理

                    //根据查询出来数据组装推送数据
                    foreach (var item in listData)
                    {
                        switch (item.ServiceInterface)
                        {
                            case "SubmitCaseProcess"://服务工单处理过程
                                var caseProcess = System.Text.Json.JsonSerializer.Deserialize<SubmitCaseProcess>(item.Data);
                                if (caseProcess != null) submitCaseProcesses.Add(caseProcess);
                                break;
                            case "SubmitCaseResult": //服务工单处理结果
                                var caseResult = System.Text.Json.JsonSerializer.Deserialize<SubmitCaseResult>(item.Data);
                                if (caseResult != null) submitCaseResults.Add(caseResult);
                                break;
                            case "SubmitVisitInfo"://服务工单回访评价
                                var visitInfo = System.Text.Json.JsonSerializer.Deserialize<SubmitVisitInfo>(item.Data);
                                if (visitInfo != null) submitVisitInfos.Add(visitInfo);
                                break;
                            case "GetCaseMaterialInfo"://附件
                                var materialInfo = System.Text.Json.JsonSerializer.Deserialize<GetCaseMaterialInfo>(item.Data);
                                if (materialInfo != null) getCaseMaterialInfos.Add(materialInfo);
                                break;
                            default:
                                break;
                        }
                    }

                    //推送对应消息
                    //服务工单处理过程
                    if (submitCaseProcesses != null && submitCaseProcesses.Count > 0) { }
                    //  await _mediator.Publish(new SubmitCaseProcessNotification(submitCaseProcesses));

                    //服务工单处理结果
                    if (submitCaseResults != null && submitCaseResults.Count > 0) { }
                    //   await _mediator.Publish(new SubmitCaseResultNotification(submitCaseResults));

                    //服务工单回访评价
                    if (submitVisitInfos != null && submitVisitInfos.Count > 0) { }
                    //  await _mediator.Publish(new SubmitVisitInfoNotification(submitVisitInfos));

                    //附件上传处理  
                    if (getCaseMaterialInfos != null && getCaseMaterialInfos.Count > 0) { }
                   // await _mediator.Publish(new GetCaseMaterialInfoNotification(getCaseMaterialInfos));
                }
                else
                {
                    await Task.Delay(time, stoppingToken);
                }
            }
        }
    }
}
