﻿using System.Reflection;
using System.Text.Json.Serialization;

namespace Sharing.Province.Dtos;

public abstract class ProvinceRequest<TData> : ProvinceRequest, IProvinceRequest<TData>
{
    [JsonPropertyName("paras")]
    public TData Data { get; set; }

    public void SetData(TData data)
    {
        Data = data;
    }

    /// <summary>
    /// 处理时间格式
    /// </summary>
    /// <typeparam name="T"></typeparam>
    /// <param name="model"></param>
    public void ForeachClass<T>(T model)
    {
        Type t = model.GetType();
        PropertyInfo[] PropertyList = t.GetProperties();
        foreach (PropertyInfo item in PropertyList)
        {
            if (item.PropertyType == typeof(DateTime?) || item.PropertyType == typeof(DateTime))
            {
                object value = item.GetValue(model, null);
                if (value != null)
                {
                    DateTime? data = Convert.ToDateTime(Convert.ToDateTime(value).ToString("yyyy-MM-dd HH:mm:ss"));
                    item.SetValue(model, data, null);
                }
            }
        }

    }
}

public abstract class ProvinceRequest : IProvinceRequest
{
    public abstract string GetRequestUrl();

    public abstract string GetHttpMethod();

    [JsonPropertyName("token")]
    public ClientInfo ClientInfo { get; set; }

    public void BuildClientInfo(string clientId, string clientSecret) =>
        ClientInfo = new ClientInfo(clientId, clientSecret);
}